Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorAlain Magloire2002-10-02 04:58:17 +0000
committerAlain Magloire2002-10-02 04:58:17 +0000
commitb1b25e2273ceb772e0cb9252a21a50d29d1f397f (patch)
tree576249e55da2c18f7678bb8147cc8116969af59e
parente1f759197d10fd624f890b3006e5bbf341b28316 (diff)
downloadorg.eclipse.cdt-b1b25e2273ceb772e0cb9252a21a50d29d1f397f.tar.gz
org.eclipse.cdt-b1b25e2273ceb772e0cb9252a21a50d29d1f397f.tar.xz
org.eclipse.cdt-b1b25e2273ceb772e0cb9252a21a50d29d1f397f.zip
add new method getRegisters().
-rw-r--r--debug/org.eclipse.cdt.debug.core/src/org/eclipse/cdt/debug/core/cdi/model/ICDITarget.java11
1 files changed, 9 insertions, 2 deletions
diff --git a/debug/org.eclipse.cdt.debug.core/src/org/eclipse/cdt/debug/core/cdi/model/ICDITarget.java b/debug/org.eclipse.cdt.debug.core/src/org/eclipse/cdt/debug/core/cdi/model/ICDITarget.java
index 404f6165481..c8876cd71cb 100644
--- a/debug/org.eclipse.cdt.debug.core/src/org/eclipse/cdt/debug/core/cdi/model/ICDITarget.java
+++ b/debug/org.eclipse.cdt.debug.core/src/org/eclipse/cdt/debug/core/cdi/model/ICDITarget.java
@@ -73,14 +73,21 @@ public interface ICDITarget extends ICDIObject {
throws CDIException;
/**
* Returns the register associated with this target.
*
* @return a collection of register groups
* @throws CDIException if this method fails. Reasons include:
*/
ICDIRegisterObject[] getRegisterObjects() throws CDIException;
/**
+ * Returns the register associated with this target.
+ * @return a collection of register.
+ * @throws CDIException if this method fails.
+ */
+ ICDIRegister[] getRegisters(ICDIRegisterObject[] regObjects) throws CDIException;
+
+ /**
* Returns a collection of global variables associated with
* this target.
*
@@ -73,14 +73,21 @@ public interface ICDITarget extends ICDIObject {
throws CDIException;
/**
- * Returns the register associated with this target.
+ * Returns the register Object associated with this target.
*
@@ -73,14 +73,21 @@ public interface ICDITarget extends ICDIObject {
*
- * @return a collection of register groups
+ * @return a collection of register object.
* @throws CDIException if this method fails. Reasons include:
*/

Back to the top